==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkconfigattributes/DefaultTeLinkAttributes.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkconfigattributes;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfschedule.rev20160301.yrtietfschedule.schedules.Schedules;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeAdminStatus;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeLinkAccessType;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.performancemetricthrottlecontainer.PerformanceMetricThrottle;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkconfigattributes.telinkattributes.Underlay;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.InterfaceSwitchingCapability;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.LinkProtectionTypeEnum;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.PerformanceMetric;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.TeSrlgs;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.UnreservedBandwidth;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.AdminGroups;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of teLinkAttributes.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultTeLinkAttributes extends InnerModelObject implements TeLinkAttributes {
    protected TeLinkAccessType accessType;
    protected boolean isAbstract;
    protected String name;
    protected TeAdminStatus adminStatus;
    protected BigInteger linkIndex;
    protected AdminGroups administrativeGroup;
    protected BigDecimal maxLinkBandwidth;
    protected BigDecimal maxResvLinkBandwidth;
    protected long teDefaultMetric;
    protected LinkProtectionTypeEnum linkProtectionType;
    protected BitSet valueLeafFlags = new BitSet();
    protected Underlay underlay;
    protected List<UnreservedBandwidth> unreservedBandwidth;
    protected PerformanceMetric performanceMetric;
    protected List<InterfaceSwitchingCapability> interfaceSwitchingCapability;
    protected TeSrlgs teSrlgs;
    protected PerformanceMetricThrottle performanceMetricThrottle;
    protected Schedules schedules;

    @Override
    public TeLinkAccessType accessType() {
        return accessType;
    }

    @Override
    public boolean isAbstract() {
        return isAbstract;
    }

    @Override
    public String name() {
        return name;
    }

    @Override
    public TeAdminStatus adminStatus() {
        return adminStatus;
    }

    @Override
    public BigInteger linkIndex() {
        return linkIndex;
    }

    @Override
    public AdminGroups administrativeGroup() {
        return administrativeGroup;
    }

    @Override
    public BigDecimal maxLinkBandwidth() {
        return maxLinkBandwidth;
    }

    @Override
    public BigDecimal maxResvLinkBandwidth() {
        return maxResvLinkBandwidth;
    }

    @Override
    public long teDefaultMetric() {
        return teDefaultMetric;
    }

    @Override
    public LinkProtectionTypeEnum linkProtectionType() {
        return linkProtectionType;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public Underlay underlay() {
        return underlay;
    }

    @Override
    public List<UnreservedBandwidth> unreservedBandwidth() {
        return unreservedBandwidth;
    }

    @Override
    public PerformanceMetric performanceMetric() {
        return performanceMetric;
    }

    @Override
    public List<InterfaceSwitchingCapability> interfaceSwitchingCapability() {
        return interfaceSwitchingCapability;
    }

    @Override
    public TeSrlgs teSrlgs() {
        return teSrlgs;
    }

    @Override
    public PerformanceMetricThrottle performanceMetricThrottle() {
        return performanceMetricThrottle;
    }

    @Override
    public Schedules schedules() {
        return schedules;
    }

    @Override
    public void accessType(TeLinkAccessType accessType) {
        valueLeafFlags.set(LeafIdentifier.ACCESSTYPE.getLeafIndex());
        this.accessType = accessType;
    }

    @Override
    public void isAbstract(boolean isAbstract) {
        valueLeafFlags.set(LeafIdentifier.ISABSTRACT.getLeafIndex());
        this.isAbstract = isAbstract;
    }

    @Override
    public void name(String name) {
        valueLeafFlags.set(LeafIdentifier.NAME.getLeafIndex());
        this.name = name;
    }

    @Override
    public void adminStatus(TeAdminStatus adminStatus) {
        valueLeafFlags.set(LeafIdentifier.ADMINSTATUS.getLeafIndex());
        this.adminStatus = adminStatus;
    }

    @Override
    public void linkIndex(BigInteger linkIndex) {
        valueLeafFlags.set(LeafIdentifier.LINKINDEX.getLeafIndex());
        this.linkIndex = linkIndex;
    }

    @Override
    public void administrativeGroup(AdminGroups administrativeGroup) {
        valueLeafFlags.set(LeafIdentifier.ADMINISTRATIVEGROUP.getLeafIndex());
        this.administrativeGroup = administrativeGroup;
    }

    @Override
    public void maxLinkBandwidth(BigDecimal maxLinkBandwidth) {
        valueLeafFlags.set(LeafIdentifier.MAXLINKBANDWIDTH.getLeafIndex());
        this.maxLinkBandwidth = maxLinkBandwidth;
    }

    @Override
    public void maxResvLinkBandwidth(BigDecimal maxResvLinkBandwidth) {
        valueLeafFlags.set(LeafIdentifier.MAXRESVLINKBANDWIDTH.getLeafIndex());
        this.maxResvLinkBandwidth = maxResvLinkBandwidth;
    }

    @Override
    public void teDefaultMetric(long teDefaultMetric) {
        valueLeafFlags.set(LeafIdentifier.TEDEFAULTMETRIC.getLeafIndex());
        this.teDefaultMetric = teDefaultMetric;
    }

    @Override
    public void linkProtectionType(LinkProtectionTypeEnum linkProtectionType) {
        valueLeafFlags.set(LeafIdentifier.LINKPROTECTIONTYPE.getLeafIndex());
        this.linkProtectionType = linkProtectionType;
    }

    @Override
    public void underlay(Underlay underlay) {
        this.underlay = underlay;
    }

    @Override
    public void unreservedBandwidth(List<UnreservedBandwidth> unreservedBandwidth) {
        this.unreservedBandwidth = unreservedBandwidth;
    }

    @Override
    public void performanceMetric(PerformanceMetric performanceMetric) {
        this.performanceMetric = performanceMetric;
    }

    @Override
    public void interfaceSwitchingCapability(List<InterfaceSwitchingCapability> interfaceSwitchingCapability) {
        this.interfaceSwitchingCapability = interfaceSwitchingCapability;
    }

    @Override
    public void teSrlgs(TeSrlgs teSrlgs) {
        this.teSrlgs = teSrlgs;
    }

    @Override
    public void performanceMetricThrottle(PerformanceMetricThrottle performanceMetricThrottle) {
        this.performanceMetricThrottle = performanceMetricThrottle;
    }

    @Override
    public void schedules(Schedules schedules) {
        this.schedules = schedules;
    }

    @Override
    public void addToUnreservedBandwidth(UnreservedBandwidth addTo) {
        if (unreservedBandwidth == null) {
            unreservedBandwidth = new ArrayList<>();
        }
        unreservedBandwidth.add(addTo);
    }


    @Override
    public void addToInterfaceSwitchingCapability(InterfaceSwitchingCapability addTo) {
        if (interfaceSwitchingCapability == null) {
            interfaceSwitchingCapability = new ArrayList<>();
        }
        interfaceSwitchingCapability.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(accessType, isAbstract, name, adminStatus, linkIndex, administrativeGroup, maxLinkBandwidth, maxResvLinkBandwidth, teDefaultMetric, linkProtectionType, valueLeafFlags, underlay, unreservedBandwidth, performanceMetric, interfaceSwitchingCapability, teSrlgs, performanceMetricThrottle, schedules);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultTeLinkAttributes) {
            DefaultTeLinkAttributes other = (DefaultTeLinkAttributes) obj;
            return
                Objects.equals(accessType, other.accessType) &&
                Objects.equals(isAbstract, other.isAbstract) &&
                Objects.equals(name, other.name) &&
                Objects.equals(adminStatus, other.adminStatus) &&
                Objects.equals(linkIndex, other.linkIndex) &&
                Objects.equals(administrativeGroup, other.administrativeGroup) &&
                Objects.equals(maxLinkBandwidth, other.maxLinkBandwidth) &&
                Objects.equals(maxResvLinkBandwidth, other.maxResvLinkBandwidth) &&
                Objects.equals(teDefaultMetric, other.teDefaultMetric) &&
                Objects.equals(linkProtectionType, other.linkProtectionType) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(underlay, other.underlay) &&
                Objects.equals(unreservedBandwidth, other.unreservedBandwidth) &&
                Objects.equals(performanceMetric, other.performanceMetric) &&
                Objects.equals(interfaceSwitchingCapability, other.interfaceSwitchingCapability) &&
                Objects.equals(teSrlgs, other.teSrlgs) &&
                Objects.equals(performanceMetricThrottle, other.performanceMetricThrottle) &&
                Objects.equals(schedules, other.schedules);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("accessType=" + accessType)
            .add("isAbstract=" + isAbstract)
            .add("name=" + name)
            .add("adminStatus=" + adminStatus)
            .add("linkIndex=" + linkIndex)
            .add("administrativeGroup=" + administrativeGroup)
            .add("maxLinkBandwidth=" + maxLinkBandwidth)
            .add("maxResvLinkBandwidth=" + maxResvLinkBandwidth)
            .add("teDefaultMetric=" + teDefaultMetric)
            .add("linkProtectionType=" + linkProtectionType)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("underlay=" + underlay)
            .add("unreservedBandwidth=" + unreservedBandwidth)
            .add("performanceMetric=" + performanceMetric)
            .add("interfaceSwitchingCapability=" + interfaceSwitchingCapability)
            .add("teSrlgs=" + teSrlgs)
            .add("performanceMetricThrottle=" + performanceMetricThrottle)
            .add("schedules=" + schedules)
            .toString();
    }


    /**
     * Creates an instance of defaultTeLinkAttributes.
     */
    public DefaultTeLinkAttributes() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkconfigattributes/DefaultTeLinkAttributes.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkconfigattributes;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtietfschedule.rev20160301.yrtietfschedule.schedules.Schedules;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeAdminStatus;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeLinkAccessType;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.performancemetricthrottlecontainer.PerformanceMetricThrottle;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkconfigattributes.telinkattributes.Underlay;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.InterfaceSwitchingCapability;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.LinkProtectionTypeEnum;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.PerformanceMetric;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.TeSrlgs;
import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.UnreservedBandwidth;
import org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.AdminGroups;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of teLinkAttributes.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultTeLinkAttributes extends InnerModelObject implements TeLinkAttributes {
    protected TeLinkAccessType accessType;
    protected boolean isAbstract;
    protected String name;
    protected TeAdminStatus adminStatus;
    protected BigInteger linkIndex;
    protected AdminGroups administrativeGroup;
    protected BigDecimal maxLinkBandwidth;
    protected BigDecimal maxResvLinkBandwidth;
    protected long teDefaultMetric;
    protected LinkProtectionTypeEnum linkProtectionType;
    protected BitSet valueLeafFlags = new BitSet();
    protected Underlay underlay;
    protected List<UnreservedBandwidth> unreservedBandwidth;
    protected PerformanceMetric performanceMetric;
    protected List<InterfaceSwitchingCapability> interfaceSwitchingCapability;
    protected TeSrlgs teSrlgs;
    protected PerformanceMetricThrottle performanceMetricThrottle;
    protected Schedules schedules;

    @Override
    public TeLinkAccessType accessType() {
        return accessType;
    }

    @Override
    public boolean isAbstract() {
        return isAbstract;
    }

    @Override
    public String name() {
        return name;
    }

    @Override
    public TeAdminStatus adminStatus() {
        return adminStatus;
    }

    @Override
    public BigInteger linkIndex() {
        return linkIndex;
    }

    @Override
    public AdminGroups administrativeGroup() {
        return administrativeGroup;
    }

    @Override
    public BigDecimal maxLinkBandwidth() {
        return maxLinkBandwidth;
    }

    @Override
    public BigDecimal maxResvLinkBandwidth() {
        return maxResvLinkBandwidth;
    }

    @Override
    public long teDefaultMetric() {
        return teDefaultMetric;
    }

    @Override
    public LinkProtectionTypeEnum linkProtectionType() {
        return linkProtectionType;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public Underlay underlay() {
        return underlay;
    }

    @Override
    public List<UnreservedBandwidth> unreservedBandwidth() {
        return unreservedBandwidth;
    }

    @Override
    public PerformanceMetric performanceMetric() {
        return performanceMetric;
    }

    @Override
    public List<InterfaceSwitchingCapability> interfaceSwitchingCapability() {
        return interfaceSwitchingCapability;
    }

    @Override
    public TeSrlgs teSrlgs() {
        return teSrlgs;
    }

    @Override
    public PerformanceMetricThrottle performanceMetricThrottle() {
        return performanceMetricThrottle;
    }

    @Override
    public Schedules schedules() {
        return schedules;
    }

    @Override
    public void accessType(TeLinkAccessType accessType) {
        valueLeafFlags.set(LeafIdentifier.ACCESSTYPE.getLeafIndex());
        this.accessType = accessType;
    }

    @Override
    public void isAbstract(boolean isAbstract) {
        valueLeafFlags.set(LeafIdentifier.ISABSTRACT.getLeafIndex());
        this.isAbstract = isAbstract;
    }

    @Override
    public void name(String name) {
        valueLeafFlags.set(LeafIdentifier.NAME.getLeafIndex());
        this.name = name;
    }

    @Override
    public void adminStatus(TeAdminStatus adminStatus) {
        valueLeafFlags.set(LeafIdentifier.ADMINSTATUS.getLeafIndex());
        this.adminStatus = adminStatus;
    }

    @Override
    public void linkIndex(BigInteger linkIndex) {
        valueLeafFlags.set(LeafIdentifier.LINKINDEX.getLeafIndex());
        this.linkIndex = linkIndex;
    }

    @Override
    public void administrativeGroup(AdminGroups administrativeGroup) {
        valueLeafFlags.set(LeafIdentifier.ADMINISTRATIVEGROUP.getLeafIndex());
        this.administrativeGroup = administrativeGroup;
    }

    @Override
    public void maxLinkBandwidth(BigDecimal maxLinkBandwidth) {
        valueLeafFlags.set(LeafIdentifier.MAXLINKBANDWIDTH.getLeafIndex());
        this.maxLinkBandwidth = maxLinkBandwidth;
    }

    @Override
    public void maxResvLinkBandwidth(BigDecimal maxResvLinkBandwidth) {
        valueLeafFlags.set(LeafIdentifier.MAXRESVLINKBANDWIDTH.getLeafIndex());
        this.maxResvLinkBandwidth = maxResvLinkBandwidth;
    }

    @Override
    public void teDefaultMetric(long teDefaultMetric) {
        valueLeafFlags.set(LeafIdentifier.TEDEFAULTMETRIC.getLeafIndex());
        this.teDefaultMetric = teDefaultMetric;
    }

    @Override
    public void linkProtectionType(LinkProtectionTypeEnum linkProtectionType) {
        valueLeafFlags.set(LeafIdentifier.LINKPROTECTIONTYPE.getLeafIndex());
        this.linkProtectionType = linkProtectionType;
    }

    @Override
    public void underlay(Underlay underlay) {
        this.underlay = underlay;
    }

    @Override
    public void unreservedBandwidth(List<UnreservedBandwidth> unreservedBandwidth) {
        this.unreservedBandwidth = unreservedBandwidth;
    }

    @Override
    public void performanceMetric(PerformanceMetric performanceMetric) {
        this.performanceMetric = performanceMetric;
    }

    @Override
    public void interfaceSwitchingCapability(List<InterfaceSwitchingCapability> interfaceSwitchingCapability) {
        this.interfaceSwitchingCapability = interfaceSwitchingCapability;
    }

    @Override
    public void teSrlgs(TeSrlgs teSrlgs) {
        this.teSrlgs = teSrlgs;
    }

    @Override
    public void performanceMetricThrottle(PerformanceMetricThrottle performanceMetricThrottle) {
        this.performanceMetricThrottle = performanceMetricThrottle;
    }

    @Override
    public void schedules(Schedules schedules) {
        this.schedules = schedules;
    }

    @Override
    public void addToUnreservedBandwidth(UnreservedBandwidth addTo) {
        if (unreservedBandwidth == null) {
            unreservedBandwidth = new ArrayList<>();
        }
        unreservedBandwidth.add(addTo);
    }


    @Override
    public void addToInterfaceSwitchingCapability(InterfaceSwitchingCapability addTo) {
        if (interfaceSwitchingCapability == null) {
            interfaceSwitchingCapability = new ArrayList<>();
        }
        interfaceSwitchingCapability.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(accessType, isAbstract, name, adminStatus, linkIndex, administrativeGroup, maxLinkBandwidth, maxResvLinkBandwidth, teDefaultMetric, linkProtectionType, valueLeafFlags, underlay, unreservedBandwidth, performanceMetric, interfaceSwitchingCapability, teSrlgs, performanceMetricThrottle, schedules);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultTeLinkAttributes) {
            DefaultTeLinkAttributes other = (DefaultTeLinkAttributes) obj;
            return
                Objects.deepEquals(accessType, other.accessType) &&
                Objects.deepEquals(isAbstract, other.isAbstract) &&
                Objects.deepEquals(name, other.name) &&
                Objects.deepEquals(adminStatus, other.adminStatus) &&
                Objects.deepEquals(linkIndex, other.linkIndex) &&
                Objects.deepEquals(administrativeGroup, other.administrativeGroup) &&
                Objects.deepEquals(maxLinkBandwidth, other.maxLinkBandwidth) &&
                Objects.deepEquals(maxResvLinkBandwidth, other.maxResvLinkBandwidth) &&
                Objects.deepEquals(teDefaultMetric, other.teDefaultMetric) &&
                Objects.deepEquals(linkProtectionType, other.linkProtectionType) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(underlay, other.underlay) &&
                Objects.deepEquals(unreservedBandwidth, other.unreservedBandwidth) &&
                Objects.deepEquals(performanceMetric, other.performanceMetric) &&
                Objects.deepEquals(interfaceSwitchingCapability, other.interfaceSwitchingCapability) &&
                Objects.deepEquals(teSrlgs, other.teSrlgs) &&
                Objects.deepEquals(performanceMetricThrottle, other.performanceMetricThrottle) &&
                Objects.deepEquals(schedules, other.schedules);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("accessType=" + accessType)
            .add("isAbstract=" + isAbstract)
            .add("name=" + name)
            .add("adminStatus=" + adminStatus)
            .add("linkIndex=" + linkIndex)
            .add("administrativeGroup=" + administrativeGroup)
            .add("maxLinkBandwidth=" + maxLinkBandwidth)
            .add("maxResvLinkBandwidth=" + maxResvLinkBandwidth)
            .add("teDefaultMetric=" + teDefaultMetric)
            .add("linkProtectionType=" + linkProtectionType)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("underlay=" + underlay)
            .add("unreservedBandwidth=" + unreservedBandwidth)
            .add("performanceMetric=" + performanceMetric)
            .add("interfaceSwitchingCapability=" + interfaceSwitchingCapability)
            .add("teSrlgs=" + teSrlgs)
            .add("performanceMetricThrottle=" + performanceMetricThrottle)
            .add("schedules=" + schedules)
            .toString();
    }


    /**
     * Creates an instance of defaultTeLinkAttributes.
     */
    public DefaultTeLinkAttributes() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
